@@ -1,4 +1,4 @@
-#!/usr/bin/env python3.8
+#!/usr/bin/env python3.9
 """Base Client API -> Models -> Pydantic Config
 Copyright © 2019-2021 Jerod Gawne <https://github.com/jerodg/>
 
@@ -29,7 +29,7 @@ class Base(PydanticBaseModel):
     Used for pydantic configuration"""
 
     class Config:
-        """Config
+        """MyConfig
 
         Pydantic configuration"""
         allow_population_by_field_name = True
